==> jc-1.4.0.tar.gz: soot/jimple/internal/JInstanceFieldRef.h <==
// public class soot.jimple.internal.JInstanceFieldRef

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2166ff1c3b2462a3 soot_jimple_internal_AbstractInstanceFieldRef
// @dep_class ff7362f213392b0a soot_jimple_internal_JInstanceFieldRef

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInstanceFieldRef

#include "soot/jimple/internal/AbstractInstanceFieldRef.h"

#ifndef _JC_soot_jimple_internal_JInstanceFieldRef_H_
#define _JC_soot_jimple_internal_JInstanceFieldRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_SootField$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JInstanceFieldRef$sub_refs	_jc_soot_jimple_internal_JInstanceFieldRef$sub_refs;
typedef struct _jc_soot_jimple_internal_JInstanceFieldRef$sub_nonrefs	_jc_soot_jimple_internal_JInstanceFieldRef$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JInstanceFieldRef$refs	_jc_soot_jimple_internal_JInstanceFieldRef$refs;
typedef struct _jc_soot_jimple_internal_JInstanceFieldRef$nonrefs	_jc_soot_jimple_internal_JInstanceFieldRef$nonrefs;
typedef struct _jc_soot_jimple_internal_JInstanceFieldRef$object	_jc_soot_jimple_internal_JInstanceFieldRef$object;

typedef const struct _jc_soot_jimple_internal_JInstanceFieldRef$vmethods	_jc_soot_jimple_internal_JInstanceFieldRef$vmethods;
typedef const struct _jc_soot_jimple_internal_JInstanceFieldRef$vtable	_jc_soot_jimple_internal_JInstanceFieldRef$vtable;
typedef const struct _jc_soot_jimple_internal_JInstanceFieldRef$vtype	_jc_soot_jimple_internal_JInstanceFieldRef$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JInstanceFieldRef$method$_init$89791f28adbff691(_jc_env *, struct _jc_soot_jimple_internal_JInstanceFieldRef$object *, struct _jc_object *, struct _jc_soot_SootField$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JInstanceFieldRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JInstanceFieldRef$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JInstanceFieldRef$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JInstanceFieldRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JInstanceFieldRef$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JInstanceFieldRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInstanceFieldRef$vmethods	soot_jimple_internal_AbstractInstanceFieldRef;
	_jc_soot_jimple_internal_JInstanceFieldRef$vmethods	soot_jimple_internal_JInstanceFieldRef;
};

// Vtype
struct _jc_soot_jimple_internal_JInstanceFieldRef$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JInstanceFieldRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInstanceFieldRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JInstanceFieldRef$refs {
    _jc_soot_jimple_internal_JInstanceFieldRef$sub_refs	soot_jimple_internal_JInstanceFieldRef;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_refs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInstanceFieldRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JInstanceFieldRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_nonrefs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_soot_jimple_internal_JInstanceFieldRef$sub_nonrefs	soot_jimple_internal_JInstanceFieldRef;
};

// Object instance structure
struct _jc_soot_jimple_internal_JInstanceFieldRef$object {
	_jc_soot_jimple_internal_JInstanceFieldRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JInstanceFieldRef$vtype	*vtype;
	_jc_soot_jimple_internal_JInstanceFieldRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JInstanceFieldRef$vtype _jc_soot_jimple_internal_JInstanceFieldRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JInstanceFieldRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JInstanceFieldRef$class_object;

#endif	/* _JC_soot_jimple_internal_JInstanceFieldRef_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JInstanceFieldRef.h <==
// public class soot.jimple.internal.JInstanceFieldRef

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2166ff1c3b2462a3 soot_jimple_internal_AbstractInstanceFieldRef
// @dep_class ff7362f213392b0a soot_jimple_internal_JInstanceFieldRef

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInstanceFieldRef

#include "soot/jimple/internal/AbstractInstanceFieldRef.h"

#ifndef _JC_soot_jimple_internal_JInstanceFieldRef_H_
#define _JC_soot_jimple_internal_JInstanceFieldRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_SootField$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JInstanceFieldRef$sub_refs	_jc_soot_jimple_internal_JInstanceFieldRef$sub_refs;
typedef struct _jc_soot_jimple_internal_JInstanceFieldRef$sub_nonrefs	_jc_soot_jimple_internal_JInstanceFieldRef$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JInstanceFieldRef$refs	_jc_soot_jimple_internal_JInstanceFieldRef$refs;
typedef struct _jc_soot_jimple_internal_JInstanceFieldRef$nonrefs	_jc_soot_jimple_internal_JInstanceFieldRef$nonrefs;
typedef struct _jc_soot_jimple_internal_JInstanceFieldRef$object	_jc_soot_jimple_internal_JInstanceFieldRef$object;

typedef const struct _jc_soot_jimple_internal_JInstanceFieldRef$vmethods	_jc_soot_jimple_internal_JInstanceFieldRef$vmethods;
typedef const struct _jc_soot_jimple_internal_JInstanceFieldRef$vtable	_jc_soot_jimple_internal_JInstanceFieldRef$vtable;
typedef const struct _jc_soot_jimple_internal_JInstanceFieldRef$vtype	_jc_soot_jimple_internal_JInstanceFieldRef$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JInstanceFieldRef$method$_init$89791f28adbff691(_jc_env *, struct _jc_soot_jimple_internal_JInstanceFieldRef$object *, struct _jc_object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JInstanceFieldRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JInstanceFieldRef$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JInstanceFieldRef$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JInstanceFieldRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JInstanceFieldRef$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JInstanceFieldRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInstanceFieldRef$vmethods	soot_jimple_internal_AbstractInstanceFieldRef;
	_jc_soot_jimple_internal_JInstanceFieldRef$vmethods	soot_jimple_internal_JInstanceFieldRef;
};

// Vtype
struct _jc_soot_jimple_internal_JInstanceFieldRef$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JInstanceFieldRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInstanceFieldRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JInstanceFieldRef$refs {
    _jc_soot_jimple_internal_JInstanceFieldRef$sub_refs	soot_jimple_internal_JInstanceFieldRef;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_refs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInstanceFieldRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JInstanceFieldRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_nonrefs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_soot_jimple_internal_JInstanceFieldRef$sub_nonrefs	soot_jimple_internal_JInstanceFieldRef;
};

// Object instance structure
struct _jc_soot_jimple_internal_JInstanceFieldRef$object {
	_jc_soot_jimple_internal_JInstanceFieldRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JInstanceFieldRef$vtype	*vtype;
	_jc_soot_jimple_internal_JInstanceFieldRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JInstanceFieldRef$vtype _jc_soot_jimple_internal_JInstanceFieldRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JInstanceFieldRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JInstanceFieldRef$class_object;

#endif	/* _JC_soot_jimple_internal_JInstanceFieldRef_H_ */
